@@ -3,7 +3,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 
 # ABSTRACT: create form fields based on a definition in a JSON file
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 use Carp;
 use File::Basename;
@@ -652,7 +652,7 @@ Mojolicious::Plugin::FormFieldsFromJSON - create form fields based on a definiti
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -850,6 +850,22 @@ You'll get
  <input id="name" name="name" type="text" value="" />
  <input id="city" name="city" type="text" value="" />
 
+=head3 dynamic config
+
+Instead of a formname, you can pass a config:
+
+  $controller->form_fields(
+    [
+      {
+        "label" : "Name",
+        "type" : "testfield",
+        "name" : "name"
+      }
+    ]
+  );
+
+This way, you can build your forms dynamically (e.g. based on database entries).
+
 =head2 validate_form_fields
 
 This helper validates the input. It uses the L<Mojolicious::Validator::Validation> and it
